@@ -7,7 +7,9 @@ use autodie;
 
 use Carp qw(confess);
 
-use version 0.77; our $VERSION = version->declare("v1.0.1");
+# The following must be on the same line to ensure that $VERSION is read
+# correctly by PAUSE and installer tools. See docu of 'version'.
+use version 0.77; our $VERSION = version->declare("v1.0.2");
 
 
 sub new {
@@ -31,7 +33,7 @@ sub new {
     for (my $i = 0; $i < @set_copy; ++$i) {
       my $entry = $set_copy[$i];
       confess("set: entry $i: invalid") if !defined($entry) || ref($entry);
-      confess("set: $entry: duplicate entry") if exists($ids{$entry});
+      confess("set: '$entry': duplicate entry") if exists($ids{$entry});
       $ids{$entry} = $i;
     }
     @{$self}{qw(prespec elems elem_ids)} = (1, \@set_copy, \%ids);
@@ -151,7 +153,7 @@ Text::Table::Read::RelationOn::Tiny - Read binary "relation on (over) a set" fro
 
 =head1 VERSION
 
-Version v1.0.1
+Version v1.0.2
 
 
 =head1 SYNOPSIS
